# overview

This module contains various Puppet extensions written to integrate with
Dell's ASM product.

It contains the following plugins:

  1. [Installation](#installation)
  1. [ASM subcommand](#asm-subcommand)
  2. [YAML Device node terminus](#yaml-device-node-terminus)
  3. [create\_resources\_with\_type function](#create_resources_with_type-function)
  4. [noop device](#noop-device)

# Installation

All of the content from this module is available when it is installed
into your local modulepath.

1. Download this module to your puppet master (or whatever node needs to utilize
   the content.)

    git clone git://github.com/bodepd/asm /etc/puppet/modules/asm

2. If you are using the yaml\_device node terminus (or the asm process\_node action which uses
   the yaml\_device node terminus), you will need to configure Puppet to use this node
   terminus for node classification.

In most cases, this would be configured for the master:

    # /etc/puppet/puppet.conf
    [master]
      node_terminus=yaml_device

Since the asm process\_node command need to use the node terminus for puppet apply as well
as puppet device (which uses the master), it should be configured in the main section
of puppet.conf.

    # /etc/puppet/puppet.conf
    [main]
      node_terminus=yaml_device

# ASM Subcommand

The _asm_ subcommand was added as the initial integration point between ASM and Puppet.

The following command can be used to display the documentation for this subcommand:

    puppet help asm

  or for information about the process\_node action

    puppet help asm process_node

process\_node is currently the only action implemented for this subcommand. This action
should be invoked for each set of configuration from a service profile (in ASM) that needs
to be applied against a single endpoint (or a single certificate).

The action expects a configuration file that expresses all resources that should be applied
to the specified certificate.

    puppet asm process_node <CERTNAME> --filename <FILE_WITH_RESOURCES>

The format of this file is as follows:

    <resource_type1>:
      <resource_title1>:
        <resource_attr1>: <attr_value1>
      <resource_title2>:
        <resource_attr2>: <attr_value2>
      ...
    <resource_type2>:
      <resource_title3>:
        <resource_attr3>: <attr_value3>
    ...

For example, the following file indicates that a notify and a few users should
be configured:

    notify:
      foo:
        message: 'foo message'
    user:
      dan:
        ensure: present
        shell:  bash
      gavin:
        ensure: present
        shell:  ksh

Invocation of the following process\_node action
does the following:

    puppet asm process_node --filename foo_resources.yaml foo --run_type apply

  - Reads a list of resources from foo\_resources.yaml.
  - writes those resources in the node data used by
    the yaml\_device node terminus (/etc/puppet/node\_data/foo.yaml).
  - Invokes

    puppet apply --certname foo -e ''.

  - Collects the following results from that run
      - number of resources in the provided file
      - number of resources that were updated
      - number of resources that were applied

## Future considerations

The process\_node subcommand is just an initial implementation and still has some issues
that will need to be resolved:

1. Multiple simultaneous invocations should work, but have not been tested.
2. For the puppet device case, it only works when the command is run on the puppet
   master. Likely it should use MCollective to support multiple device nodes.
3. All of the edge cases around what to do when defined resources already exist in
   a device.conf file have not yet been resolved. The current behavior is as follows:

   * If the flag --always-override is supplied, any existing files will be overridden.

   * If the device.conf file does not exist, a new one will be created.

   * If the device.conf file exists and already has a resource matching the type/title
   from any resources from the provided configuration file, the command fails.

   This behavior is not sufficient for supporting updates to service profiles. It will
   have to be updated to support this behavior.

# YAML Device Node Terminus

This module contains puppet plug-ins that allow resources for a device
to be specified in an external yaml file.

This classification information is stored in the following per node file:

    $confdir/node_data/<certname>.yaml

## config file format

Resources are added to each device by providing the following in _devices.yaml_.

````
certname:
  resources:
    resource_type:
      resource_param_one: resource_param_value
````


Classes as well as parameters can also be added:

````
certname:
  classes:
    one:
    two:
    three:
  parameters:
    param1: value1
````

**NOTE** Classes cannot be supplied as a list if resources are also supplied.

## Running a simple node terminus integration test

The following instructions demonstrate how to run a simple integration test:

Run the following commands from the top level directory of this module:

1. First fire up a puppet master:

    puppet master --certname localhost --confdir tests/test_conf_dir/ --modulepath ../ --trace --debug --ssldir tests/test_conf_dir/master_ssl --no-daemonize --user root

2. Now connect a device:

    puppet device  --confdir tests/test_conf_dir/ --modulepath ../ --server localhost --certname device1 --debug --no-daemonize --ssldir tests/test_conf_dir/ssl --user root --noop

# create\_resources\_with\_type function

This module also contains a simple custom function that can be used to specify a hash of
resources with types supplied. This function was necessary to support adding resources from
the ENC.

# Noop Device

A simple noop device for Puppet was added that doesn't do anything. This was added to make testing
easier.

# to run unit tests

First install bundler and rubygems.

To run tests:

    bundle install
    bundle exec rake spec

# Creating an RPM

    clone https://github.com/dell-asm/module-rpm (folder name = module-rpm)
    clone https://github.com/dell-asm/asm (folder name = modules/asm)
    checkout desired branch
    cd module-rpm
    gradle
    sign your rpm


