require 'puppet'
require 'puppet/util/network_device'

module Puppet::ASM::Device

  def self.device_filename(certname)
    File.join('/etc', 'puppetlabs', 'puppet', 'devices', "#{certname}.conf")
  end

  def self.device_ssl_dir(certname)
    "/var/opt/lib/pe-puppet/devices/#{certname}/ssl"
  end

  def self.update_inventory(certname)
    require 'puppet/util/network_device/config'
    Puppet[:ssldir]       = device_ssl_dir(certname)
    Puppet[:certname]     = certname
    Puppet[:deviceconfig] = device_filename(certname)
    # get the first device defined in our device config file
    device = Puppet::Util::NetworkDevice::Config.devices.values.first
    # initialize the device configuration
    Puppet::Util::NetworkDevice.init(device)
    # set facts to use network_device
    Puppet::Node::Facts.indirection.terminus_class = :network_device
    Puppet.debug("Retreving facts for #{certname}")
    facts = Puppet::Node::Facts.indirection.find(certname)
    # switch back to rest interface (to send them to the master)
    Puppet::Node::Facts.indirection.terminus_class = :rest
    # upload facts to puppet
    Puppet::Node::Facts.indirection.save(facts)
    Puppet.notice("Uploaded retrieved facts for #{certname}")
    facts
  end

end
