#
# Copyright Dell 2013
#
Puppet::Parser::Functions::newfunction(
  :create_resources_with_type,
  :arity => 1,
  :doc => <<-'ENDHEREDOC') do |args|

  This function wraps create_resources and allows for the types of the
  resources created to be specified in the provided hash of resources.

  The following example invocation creates a heterogeneous set of
  resources:

    create_resources_with_type(
      {
        'user' => {
          'dan' => {'ensure' => 'present'},
          'bob' => {'ensure' => 'present'}
        },
        'group' => {
          'admin2' => {'ensure' => 'present'},
          'admin3' => {'ensure' => 'present'}
        }
      }
    )

  ENDHEREDOC

  resource_hash = args.first

  unless resource_hash.class == Hash
    raise(ArgumentError, "Expects a hash, got a #{resource_hash.class}")
  end

  args.first.each do |type, resources|
    # load create_resources
    raise(ArgumentError, 'Type must be a string') unless type.class == String
    raise(ArgumentError, 'Resources must be a hash') unless resources.class == Hash
    Puppet::Parser::Functions.function(:create_resources)
    function_create_resources([type.capitalize, resources])
  end

end
