require 'json'
require 'fileutils'
require 'tmpdir'

module Puppet::Parser::Functions
  newfunction(:exe_to_bmc_fw, :type => :rvalue, :doc => <<-EOS
This function takes in the bmc_firmware string with uri_path as the 
full path and converts it to an array of hashes that the bmc_fw_ipmiflash module can us.
  EOS
  ) do |args|

    UNZIP = %x[which unzip].chop
    FIND = %x[which find].chop

    og_firmware = args[0]
    firmwares = JSON.parse(og_firmware)
    asm_host = args[1]
    tftp_share = args[2]
    firmware_repo_id = args[3]
    firmwares.each do |firmware|
      # This is the path to the origin exe (we need to extract this)
      exe_path = firmware["location"]
      temp_dir = Dir.mktmpdir
      destination_dir = "#{tftp_share}/#{firmware_repo_id}"
      # Extract to a temp dir as we won't need most files
      %x[#{UNZIP} -d #{temp_dir} #{exe_path}]
      # Find the hdr binary that we need
      hdr_path = %x[#{FIND} #{temp_dir}/ -type f -name '*.hdr'].chop
      file_name = File.basename(hdr_path)
      # Copy the hdr to the tftp_share
      if !File.exist? destination_dir
        FileUtils.mkdir destination_dir
      end
      FileUtils.cp hdr_path, "#{destination_dir}/"
      FileUtils.chmod_R 0755, destination_dir
      # Remove the tempdir
      FileUtils.remove_entry temp_dir
      newpath = "#{destination_dir}/#{file_name}"
      relative_path = newpath.split(tftp_share)[1]
      uri = "tftp://#{asm_host}#{relative_path}"
      firmware["location"] = uri
    end
  firmwares
  end
end

