require 'fileutils'
require 'uri'

module Puppet::Parser::Functions
  newfunction(:nfs_to_tftp, :type => :rvalue, :doc => <<-EOS
This function takes the current nfs location, the tftp host, and the tftp root directory
and moves the original file to the tftp share. Returning the new URL.
  EOS
  ) do |args|

    og_firmware = args[0]
    tftp_url = args[1]
    tftp_share = args[2]


    Puppet.debug("copying firmware from NFS share: #{og_firmware} to TFTP share")

    uri = URI.parse(tftp_url)
    destination_dir = uri.path.split('/')[1]
    file_name = File.basename(uri.path)

    destination = File.join(tftp_share,destination_dir,file_name)

    if !File.exist? destination
      if !File.exist? File.dirname(destination)
        FileUtils.mkdir File.dirname(destination)
      end
      FileUtils.cp og_firmware, destination
      FileUtils.chmod_R 0755, destination
    end

    image_url = uri.scheme + "://" + uri.hostname + "/" + destination_dir + "/" + file_name
    image_url
  end
end
