# scvmm cluster
define asm::cluster::scvmm (
  $ipaddress,
  $host_group,
  $scvmm_server,
  $hosts,
  $username,
  $password,
  $ensure                       = present,
  $run_as_account_name          = undef,
  $fqdn                         = undef,
  $logical_network              = 'ConvergedNetSwitch',
  $logical_network_hostgroups   = [],
  $logical_network_subnet_vlans = [],
  $vm_network                   = 'ConvergedNetSwitch',
  $options                      = { 'timeout' => 600 }
) {

  if !defined(Transport[$scvmm_server]) {
    transport { $scvmm_server:
      options  => $options,
      provider => 'device_file',
    }
  }

  if !defined(Scvm_host_group[$host_group]) {
    scvm_host_group { $host_group:
      ensure    => $ensure,
      transport => Transport[$scvmm_server],
    }
  }

  if $run_as_account_name {
    sc_run_as_account { $run_as_account_name:
      ensure    => $ensure,
      username  => $username,
      password  => $password,
      transport => Transport[$scvmm_server],
      provider  => asm_decrypt, # This decodes the password.
    }
  }

  scvm_host { $hosts:
    ensure             => $ensure,
    path               => $host_group,
    management_account => $run_as_account_name,
    username           => $username,
    password           => $password,
    transport          => Transport[$scvmm_server],
    provider           => asm_decrypt, # This decodes the password.
  }

  scvm_host_cluster { $name:
    ensure            => $ensure,
    hosts             => $hosts,
    cluster_ipaddress => $ipaddress,
    path              => $host_group,
    username          => $username,
    password          => $password,
    fqdn              => $fqdn,
    inclusive         => false,
    require           => Scvm_host[$hosts],
    transport         => Transport[$scvmm_server],
    provider          => asm_decrypt, # This decodes the password.
  }

  scvm_cluster_storage { $name:
    ensure    => $ensure,
    host      => $hosts[0],
    path      => $host_group,
    username  => $username,
    password  => $password,
    fqdn      => $fqdn,
    require   => Scvm_host_cluster[$name],
    transport => Transport[$scvmm_server],
    provider  => asm_decrypt, # This decodes the password.
  }

  sc_logical_network { $logical_network:
    ensure                               => $ensure,
    logical_network_definition_isolation => false,
    enable_network_virtualization        => true,
    use_gre                              => true,
    is_pvlan                             => false,
    transport                            => Transport[$scvmm_server],
    require                              => Scvm_cluster_storage[$name]
  }

  sc_logical_network_definition { $logical_network:
    ensure          => $ensure,
    logical_network => $logical_network,
    host_groups     => $logical_network_hostgroups,
    subnet_vlans    => $logical_network_subnet_vlans,
    inclusive       => false,
    transport       => Transport[$scvmm_server],
  }

  sc_vm_network { $vm_network:
    ensure          => $ensure,
    description     => '',
    logical_network => $logical_network,
    transport       => Transport[$scvmm_server],
  }
}

