# Define: asm datastore
define asm::datastore(
  $data_center,
  $datastore,
  $cluster,
  $esxhost,
  $esxusername,
  $esxpassword,
  $ensure          = present,
  $chapname        = undef,
  $chapsecret      = undef,
  $esxclipath      = '/usr/bin/esxcli',
  $hba_titles        = [ "${esxhost}:vmhba33:${datastore}", "${esxhost}:vmhba34:${datastore}" ],
  $hba_hash        = {
    '172.28.119.1:vmhba32:deviscsitermz' => {
      'vmhba'   => 'vmhba32',
      'vmknics' => 'vmk2'
    },
    '172.28.119.1:vmhba33:deviscsitermz' => {
      'vmhba'   => 'vmhba33',
      'vmknics' => 'vmk3'
    }
  },
  $iscsi_target_ip = '',
  $lun             = '0',
  $decrypt         = false,
  $software_iscsi  = false,
) {

  if $decrypt {
    $provider = 'asm_decrypt'
  } else {
    $provider = undef
  }

  if $chapname {
    $chap_auth = true
    $chap_auth_type = 'chapPreferred'
  } else {
    $chap_auth = false
  }

  # Add iscsi intitiator port bindings.
  asm::datastore::each_hba { $hba_titles:
    hba_hash               => $hba_hash,
    esxclipath             => $esxclipath,
    esxusername            => $esxusername,
    esxpassword            => $esxpassword,
    provider               => $provider,
    ensure                 => $ensure,
    chapname               => $chapname,
    chapsecret             => $chapsecret,
    iscsi_target_ip        => $iscsi_target_ip,
    lun                    => $lun,
    chap_auth              => $chap_auth,
    chap_auth_type         => $chap_auth_type,
    software_iscsi         => $software_iscsi
  }
}
