# Define: asm ESX iSCSI config
define asm::esxiscsiconfig(
  $data_center,
  $datastore,
  $cluster,
  $vcenter_username,
  $vcenter_password,
  $vcenter_server,
  $vcenter_options,
  $esxhost,
  $esxusername,
  $esxpassword,
  $ensure                = present,
  $vmotionipsetting      = 'dhcp',
  $vmotionipaddress      = '',
  $vmotionsubnet         = '',
  $vmotionvlanid         = '0',
  $iscsinic1ipsetting    = 'dhcp',
  $iscsinic1ipaddress    = '',
  $iscsinic1subnetmask   = '',
  $iscsisnic2ipsetting   = 'dhcp',
  $iscsinic2ipaddress    = '',
  $iscsinic2subnetmask   = '',
  $iscsivlanid           = '0',
  $esxclipath            = '/usr/bin/esxcli',
  $hba1                  = 'vmhba33',
  $hba2                  = 'vmhba34',
  $iscsi_target_ip       = '',
) {

  transport { 'vcenter':
    username => $vcenter_username,
    password => $vcenter_password,
    server   => $vcenter_server,
    options  => $vcenter_options,
  }

  $iscsi_details = {
    # Provide space separated VMkernel nics
    'vmknics'                     => 'vmk2',
    'vmknics1'                     => 'vmk3',
  }

  vc_host { $esxhost:
    ensure    => $ensure,
    path      => "/${data_center}/${cluster}",
    username  => $esxusername,
    password  => $esxpassword,
    transport => Transport['vcenter'],
  }

  # adding vswitch0 on esx

  esx_vswitch { "${esxhost}:vSwitch0":
    ensure             => $ensure,
    path               => "/${data_center}/${cluster}",
    num_ports          => 1024,
    nics               => ['vmnic0', 'vmnic1'],
    nicorderpolicy     => {
      activenic  => ['vmnic0'],
      standbynic => ['vmnic1'],
    },
    mtu                => 9000,
    checkbeacon        => false,
    transport          => Transport['vcenter'],
  } ~>

  # adding vswitch1 on esx
  esx_vswitch { "${esxhost}:vSwitch1":
    ensure         => $ensure,
    path           => "/${data_center}/${cluster}",
    num_ports      => 1024,
    nics           => ['vmnic2', 'vmnic3'],
    nicorderpolicy => {
      activenic  => ['vmnic3'],
      standbynic => ['vmnic2'],
    }
    ,
    mtu            => 9000,
    checkbeacon    => true,
    transport      => Transport['vcenter'],
  } ~>

  # add portgroup on vswitch1

  esx_portgroup { 'name0':
    ensure                 => $ensure,
    name                   => "${esxhost}:vMotion",
    portgrouptype          => 'VMkernel',
    overridefailback       => 'disabled',
    failback               => true,
    mtu                    => '9000',
    overridefailoverorder  => 'enabled',
    nicorderpolicy         => {
      activenic  => ['vmnic2'],
      standbynic => ['vmnic3'],
    },
    overridecheckbeacon    => 'enabled',
    checkbeacon            => true,
    vmotion                => 'enabled',
    ipsettings             => $vmotionipsetting,
    ipaddress              => $vmotionipaddress,
    subnetmask             => $vmotionsubnet,
    traffic_shaping_policy => 'disabled',
    averagebandwidth       => 1000,
    peakbandwidth          => 1000,
    burstsize              => 1024,
    vswitch                => vSwitch1,
    host                   => $esxhost,
    path                   => "/${data_center}/${cluster}",
    vlanid                 => $vmotionvlanid,
    transport              => Transport['vcenter'],
  } ~>

  # add vswitch2

  esx_vswitch {  "${esxhost}:vSwitch2":
    ensure         => $ensure,
    path           => "/${data_center}/${cluster}",
    num_ports      => 1024,
    #  failback => "false",
    nics           => ['vmnic5', 'vmnic4'],
    nicorderpolicy => {
      activenic  => ['vmnic4', 'vmnic5'],
    }
    ,
    mtu            => 9000,
    checkbeacon    => true,
    transport      => Transport['vcenter'],
  } ~>

  # add portgroup on vswitch2

  esx_portgroup { 'name2':
    ensure                 => $ensure,
    name                   => "${esxhost}:VM-Workload-32",
    portgrouptype          => 'VirtualMachine',
    overridefailback       => 'disabled',
    failback               => true,
    mtu                    => '9000',
    overridefailoverorder  => 'enabled',
    nicorderpolicy         => {
      activenic  => ['vmnic5', 'vmnic4'],
    },
    overridecheckbeacon    => 'enabled',
    checkbeacon            => true,
    #  vmotion => "disabled",
    ipsettings             => 'static',
    traffic_shaping_policy => 'disabled',
    averagebandwidth       => 1000,
    peakbandwidth          => 1000,
    burstsize              => 1024,
    vswitch                => vSwitch2,
    host                   => $esxhost,
    path                   => "/${data_center}/${cluster}",
    transport              => Transport['vcenter'],
  } ~>

  # Add vswitch3

  esx_vswitch { "${esxhost}:vSwitch3":
    ensure         => $ensure,
    path           => "/${data_center}/${cluster}",
    num_ports      => 1024,
    nics           => ['vmnic6', 'vmnic7'],
    nicorderpolicy => {
      activenic  => ['vmnic6', 'vmnic7'],
    }
    ,
    mtu            => 9000,
    checkbeacon    => true,
    transport      => Transport['vcenter'],
  } ~>

  # Add portgroups iscsi1&iscsi2 on vswitch3

  esx_portgroup { 'name4':
    ensure                 => $ensure,
    name                   => "${esxhost}:iSCSI1",
    portgrouptype          => 'VMkernel',
    overridefailback       => 'enabled',
    failback               => false,
    mtu                    => '9000',
    overridefailoverorder  => 'enabled',
    nicorderpolicy         => {
      activenic  => ['vmnic6'],
      unusednic  => ['vmnic7'],
    },
    overridecheckbeacon    => 'enabled',
    checkbeacon            => true,
    ipsettings             => $iscsisnic1ipsetting,
    ipaddress              => $iscsinic1ipaddress,
    subnetmask             => $iscsinic1subnetmask,
    traffic_shaping_policy => 'disabled',
    averagebandwidth       => 1000,
    peakbandwidth          => 1000,
    burstsize              => 1024,
    vswitch                => vSwitch3,
    host                   => $esxhost,
    path                   => "/${data_center}/${cluster}",
    vlanid                 => $iscsivlanid,
    transport              => Transport['vcenter'],
  } ~>

  esx_portgroup { 'name5':
    ensure                 => $ensure,
    name                   => "${esxhost}:iSCSI2",
    portgrouptype          => 'VMkernel',
    overridefailback       => 'enabled',
    failback               => false,
    mtu                    => '9000',
    overridefailoverorder  => 'enabled',
    nicorderpolicy         => {
      activenic  => ['vmnic7'],
      unusednic  => ['vmnic6'],
    },
    overridecheckbeacon    => 'enabled',
    checkbeacon            => true,
    #  vmotion => "disabled",
    ipsettings             => $iscsisnic2ipsetting,
    ipaddress              => $iscsinic2ipaddress,
    subnetmask             => $iscsinic1subnetmask,
    traffic_shaping_policy => 'disabled',
    averagebandwidth       => 1000,
    peakbandwidth          => 1000,
    burstsize              => 1024,
    vswitch                => vSwitch3,
    host                   => $esxhost,
    path                   => "/${data_center}/${cluster}",
    vlanid                 => $iscsivlanid,
    transport              => Transport['vcenter'],
  } ~>

  # give iscsi nic details

  # Add iscsi intitiator port bindings.

  iscsi_intiator_binding { "${esxhost}:${hba1}":
    ensure                    => $ensure,
    vmknics                   => $iscsi_details['vmknics'],
    script_executable_path    => $esxclipath,
    host_username             => $esxusername,
    host_password             => $esxpassword,
    transport                 => Transport['vcenter'],
  } ~>

  iscsi_intiator_binding { "${esxhost}:${hba2}":
    ensure                    => $ensure,
    vmknics                   => $iscsi_details['vmknics1'],
    script_executable_path    => $esxclipath,
    host_username             => $esxusername,
    host_password             => $esxpassword,
    transport                 => Transport['vcenter'],
  } ~>

  # Add iscsi send targets

  vcenter::iscsi_send_target { "${esxhost}:${hba1}":
    ensure                    => $ensure,
    targets                   => {
      address          => $iscsi_target_ip,
      port             => 3260,
      advanced_options => [ {
        key         => 'DelayedAck',
        value       => true,
        isInherited => false
      } ],
    },
    transport                 => Transport['vcenter'],
  } ~>


  vcenter::iscsi_send_target { "${esxhost}:${hba2}":
    ensure                    => $ensure,
    targets                   => {
      address          => $iscsi_target_ip,
      port             => 3260,
      advanced_options => [ {
        key         => 'DelayedAck',
        value       => true,
        isInherited => false
      } ],
    },
    transport                 => Transport['vcenter'],
  } ~>

  exec{ 'wait1':
    command => '/bin/sleep 1',
  } ~>

  # Rescan all hbas.

  esx_rescanallhba {'host':
    ensure      => $ensure,
    host        => $esxhost,
    path        => "/${data_center}/${cluster}",
    transport   => Transport['vcenter'],
  } ~>

  exec{ 'wait':
    command => '/bin/sleep 1',
  } ~>

  # add datastore with lun number
  esx_datastore { "${esxhost}:esx_datastore":
    ensure       => $ensure,
    # before => Esx_mem["$mem"],
    type         => 'vmfs',
    lun          => '0',
    transport    => Transport['vcenter'],
    require      => Esx_rescanallhba['host'],
  }

  ####configure MEM
  # esx_mem { "$mem":
  ##require => Esx_rescanallhba['host'],
  # require => Esx_datastore ["$esxhost:arpl800test"],
  ##configure_mem                 => "true",
  # install_mem               => "true",
  # script_executable_path    => $mem1['script_executable_path'],
  # setup_script_filepath     => $mem1['setup_script_filepath'],
  # host_username             => $mem1['host_username'],
  # host_password             => $mem1['host_password'],
  # transport                 => Transport['vcenter'],
  # }

}
