# This defined resource configures iDrac hosts based on iDrac
# configuration xml.
#
# Parameters:
# - $target_boot_device - Either SD or HD for SD card or Hard Drive
#   boot
# - $servicetag - The Dell server service tag, e.g. JH870W1
# - $model - The Dell server model, e.g. m420, m620, m820, r620, r720.
#   This will be used to determine which XML template to use. If no
#   match is found default.xml.erb will be used
# - $nfsipaddress - The IP address of the NFS server
# - $nfssharepath - The nfs path hosting the iDrac config file
# - $nfslocaldir - The local path to the NFS share. The iDrac
#   configuration file will be written here.
# - $sysprofile - power setting as configured in idrac via sysprofile
# - $enable_npar - Whether nic partitioning should be enabled
# - $config_xml - An xml blob of the config.xml data to parse/edit (from cloned server)
# - $network_configuration - Hash of network configurations for BFS $target_boot_device
# - $raid_config - Raid configuration based on raid_config settings
# - $raid_configuration - Hash that has information on how to configure the virtual disks

define asm::idrac(
  $servicetag,
  $nfsipaddress           = undef,
  $model                  = '',
  $nfssharepath           = '/var/nfs/idrac_config_xml',
  $target_boot_device     = undef,
  $enable_npar            = undef,
  #TODO:  config_xml is a placeholder variable until we can remove it from asm-core/asm-deployer completely
  $config_xml             = undef,
  $raid_configuration     = undef,
  $server_pool            = undef,
  $network_configuration  = undef,
  $bios_settings          = undef,
  $target_ip              = undef,
  $target_iscsi           = undef,
  $force_reboot           = false,
  $ensure                 = present
) {

  powerstate {"${servicetag}_power_on":
    ensure  => on,
  }

  importsystemconfiguration { $servicetag :
    configxmlfilename   => "${servicetag}.xml",
    nfsipaddress        => $nfsipaddress,
    nfssharepath        => $nfssharepath,
    servicetag          => $servicetag,
    model               => $model,
    target_boot_device  => $target_boot_device,
    raid_configuration  => $raid_configuration,
    network_config      => $network_configuration,
    target_ip           => $target_ip,
    target_iscsi        => $target_iscsi,
    bios_settings       => $bios_settings,
    force_reboot        => $force_reboot,
    ensure              => $ensure,
    require             => Powerstate["${servicetag}_power_on"],
  }

}
