# Define: force10::force10_add_vlan
#
# Utility for adding vlan in Force10 switch.
#
# === Parameters:
#
# === Actions:
#
# === Requires:
#
# === Sample Usage:
#  force10::force10_add_vlan {'123':
#      tagged_tengigabitethernet => '0/8-16,20-25,27,28',
#      tagged_portchannel => '1,2,3,4,10,20,30,40',
#      mtu => 1500,
#  }
#
define asm::iom (
  $vlan_name                   = '',
  $desc                        = '',
  $tagged_tengigabitethernet   = '',
  $tagged_portchannel          = '',
  $untagged_tengigabitethernet = '',
  $mtu                         = '1500',
  $ensure                      = present
) {
  if $vlan_name == '' {
    $vname = "VLAN_${name}"
  }
  else {
    $vname = $vlan_name
  }

  if $desc == '' {
    $vdesc = "VLAN ${name} created by ASM"
  }
  else {
    $vdesc = $desc
  }

  if empty($untagged_tengigabitethernet) {
    if empty($tagged_tengigabitethernet) {
      if empty($tagged_portchannel) {
        force10_vlan {$name:
          vlan_name => $vname,
          desc      => $vdesc,
          shutdown  => false,
          mtu       => $mtu,
        }
      }
      else {
        force10_vlan {$name:
          vlan_name          => $vname,
          desc               => $vdesc,
          shutdown           => false,
          tagged_portchannel => $tagged_portchannel,
          mtu                => $mtu,
        }
      }
    }
    else {
      if empty($tagged_portchannel) {
        force10_vlan {$name:
          vlan_name                 => $vname,
          desc                      => $vdesc,
          shutdown                  => false,
          tagged_tengigabitethernet => $tagged_tengigabitethernet,
          mtu                       => $mtu,
        }
      }
      else {
        force10_vlan {$name:
          vlan_name                 => $vname,
          desc                      => $vdesc,
          shutdown                  => false,
          tagged_tengigabitethernet => $tagged_tengigabitethernet,
          tagged_portchannel        => $tagged_portchannel,
          mtu                       => $mtu,
        }
      }
    }
  }
  else {
    if empty($tagged_tengigabitethernet) {
      if empty($tagged_portchannel) {
        force10_vlan {$name:
          vlan_name                   => $vname,
          desc                        => $vdesc,
          shutdown                    => false,
          untagged_tengigabitethernet => $untagged_tengigabitethernet,
          mtu                         => $mtu,
        }
      }
      else {
        force10_vlan {$name:
          vlan_name                   => $vname,
          desc                        => $vdesc,
          shutdown                    => false,
          untagged_tengigabitethernet => $untagged_tengigabitethernet,
          tagged_portchannel          => $tagged_portchannel,
          mtu                         => $mtu,
        }
      }
    }
    else {
      if empty($tagged_portchannel) {
        force10_vlan {$name:
          vlan_name                   => $vname,
          desc                        => $vdesc,
          shutdown                    => false,
          tagged_tengigabitethernet   => $tagged_tengigabitethernet,
          untagged_tengigabitethernet => $untagged_tengigabitethernet,
          mtu                         => $mtu,
        }
      }
      else {
        force10_vlan {$name:
          vlan_name                   => $vname,
          desc                        => $vdesc,
          shutdown                    => false,
          untagged_tengigabitethernet => $untagged_tengigabitethernet,
          tagged_tengigabitethernet   => $tagged_tengigabitethernet,
          tagged_portchannel          => $tagged_portchannel,
          mtu                         => $mtu,
        }
      }
    }
  }
}

