# Define: ASM mxl
define asm::mxl (
  $vlan_name                    = '',
  $desc                         = '',
  $tagged_tengigabitethernet    = '',
  $tagged_portchannel           = '',
  $untagged_tengigabitethernet  = '',
  $mtu                          = '9000',
  $feature                      = '',
  $fc_map                       = '',
  $ensure                       = present,
  $dcb_map_name                 = undef,
  $dcb_priority_group_info      = { 0 => { 'bandwidth' => '60', 'pfc' => 'off' },
                                    1 => { 'bandwidth' => '40', 'pfc' => 'on' }
                                  },
  $dcb_priority_pgid            = '0 0 0 1 0 0 0 0',
  $fcoe_map_name                = undef,
  $fcoe_map                     = undef,
  $fcoe_interface               = undef,
  $uplink_state_group           = '1',
  $upstream_interface           = 'Port-channel 128',
  $downstream_property          = 'auto-recover'
) {
  if $vlan_name == '' {
    $vname = "VLAN_${name}"
  }
  else {
    $vname = $vlan_name
  }


  if $desc == '' {
    $vdesc = "VLAN ${name} created by ASM"
  }
  else {
    $vdesc = $desc
  }

  if !empty($feature) {
    if $feature == 'fc'
    {
      force10_feature {$feature: }
      mxl_dcbmap { $dcb_map_name:
        priority_group_info => $dcb_priority_group_info,
        priority_pgid       => $dcb_priority_pgid
      }
      mxl_fcoemap { $fcoe_map_name:
        fcoe_map  => $fcoe_map,
        fcoe_vlan => $name
      }
      mxl_interface { $fcoe_interface:
        dcb_map  => $dcb_map_name,
        fcoe_map => $fcoe_map_name,
        shutdown => false
      }
      mxl_uplinkstategroup { $uplink_state_group:
        downstream_interface => $fcoe_interface,
        upstream_interface   => $upstream_interface,
        downstream_property  => $downstream_property
      }
    }
    if $feature == 'fip-snooping' {
      force10_feature {$feature: }
    }
  }

  if empty($untagged_tengigabitethernet) {
    if empty($tagged_tengigabitethernet) {
      if empty($tagged_portchannel) {
        mxl_vlan {$name:
          ensure    => $ensure,
          vlan_name => $vname,
          desc      => $vdesc,
          shutdown  => false,
          fc_map    => $fc_map
        }
      }
      else {
        mxl_vlan {$name:
          ensure             => $ensure,
          vlan_name          => $vname,
          desc               => $vdesc,
          shutdown           => false,
          tagged_portchannel => $tagged_portchannel,
          fc_map             => $fc_map
        }
      }
    }
    else {
      if empty($tagged_portchannel) {
        mxl_vlan {$name:
          ensure                    => $ensure,
          vlan_name                 => $vname,
          desc                      => $vdesc,
          shutdown                  => false,
          tagged_tengigabitethernet => $tagged_tengigabitethernet,
          fc_map                    => $fc_map
        }
      }
      else {
        mxl_vlan {$name:
          ensure                    => $ensure,
          vlan_name                 => $vname,
          desc                      => $vdesc,
          shutdown                  => false,
          tagged_tengigabitethernet => $tagged_tengigabitethernet,
          tagged_portchannel        => $tagged_portchannel,
          fc_map                    => $fc_map
        }
      }
    }
  }
  else {
    if empty($tagged_tengigabitethernet) {
      if empty($tagged_portchannel) {
        mxl_vlan {$name:
          ensure                      => $ensure,
          vlan_name                   => $vname,
          desc                        => $vdesc,
          shutdown                    => false,
          untagged_tengigabitethernet => $untagged_tengigabitethernet,
          fc_map                      => $fc_map
        }
      }
      else {
        mxl_vlan {$name:
          ensure                      => $ensure,
          vlan_name                   => $vname,
          desc                        => $vdesc,
          shutdown                    => false,
          untagged_tengigabitethernet => $untagged_tengigabitethernet,
          tagged_portchannel          => $tagged_portchannel,
          fc_map                      => $fc_map
        }
      }
    }
    else {
      if empty($tagged_portchannel) {
        mxl_vlan {$name:
          ensure                      => $ensure,
          vlan_name                   => $vname,
          desc                        => $vdesc,
          shutdown                    => false,
          tagged_tengigabitethernet   => $tagged_tengigabitethernet,
          untagged_tengigabitethernet => $untagged_tengigabitethernet,
          fc_map                      => $fc_map
        }
      }
      else {
        mxl_vlan {$name:
          ensure                      => $ensure,
          vlan_name                   => $vname,
          desc                        => $vdesc,
          shutdown                    => false,
          untagged_tengigabitethernet => $untagged_tengigabitethernet,
          tagged_tengigabitethernet   => $tagged_tengigabitethernet,
          tagged_portchannel          => $tagged_portchannel,
          fc_map                      => $fc_map
        }
      }
    }
  }

}
