#
# == Define: dell_powerconnect::powerconnect_add_vlan
#
# Utility for adding vlan in Powerconnect switch.
#
# === Parameters:
#
# === Actions:
#
# === Requires:
#
# === Sample Usage:
#  dell_powerconnect::powerconnect_add_vlan {'123':
#      portchannel => '1, 2, 3',
#      interface => 'Gi1/0/1, Gi1/0/2, Gi1/0/3',
#  }
#
define asm::powerconnect(
  $ensure                = present,
  $vlan_name             = '',
  $portchannel           = '',
  $interface             = '',
  $mode                  = 'general'
) {
  $port_channel_array = strip(split($portchannel, ','))
  $interface_array = strip(split($interface, ','))

  if $vlan_name == '' {
    $vname = "VLAN_${name}"
  }
  else {
    $vname = $vlan_name
  }

  powerconnect_vlan{$name:
    ensure    => $ensure,
    vlan_name => $vname,
  }

  if size($interface_array) != 0 {
    powerconnect_interface{$interface_array:
      mode                   => 'general',
      add_vlans_general_mode => $name,
      shutdown               => false,
      require                => Powerconnect_vlan[$name],
    }
  }

  if size($port_channel_array) != 0 {
    powerconnect_portchannel{$port_channel_array:
      allowvlans => $name,
      require    => Powerconnect_vlan[$name],
    }
  }
}
