# Define: ASM Server
define asm::server(
  $razor_image,
  $admin_password,
  $os_host_name,
  $iscsi_initiator = 'hardware',
  $serial_number,
  $policy_name,
  #os_image_type is not actually used anymore on this end, but it's tricky to "disconnect" from the asm-deployer code.
  $os_image_type              = undef,
  $os_image_version           = undef,
  $broker_type                = 'noop',
  $ensure                     = present,
  #
  # in this case decrypt does nothing b/c we forward the encrypted
  # password, I think the real fix is not to mark this as PASSWORD
  # type
  #
  $decrypt                    = false,
  $installer_options          = {},
  $esx_mem                    = '',
  $local_storage_vsan         = false,
  $razor_api_options          = { 'url' => 'http://localhost:8080' }
) {

  if empty($installer_options){
    $metadata = {}
  }
  else{
    $metadata = {'installer_options'=> $installer_options}
  }

  transport { 'razor':
    options => $razor_api_options
  }

  rz_tag { "${name}_tag" :
    ensure => $ensure,
    rule   => ['and', ['=', ['fact', 'serialnumber'], $serial_number]],
    transport => Transport['razor']
  }

  rz_policy { $policy_name:
    ensure        => $ensure,
    enabled       => true,
    repo          => $razor_image,
    root_password => $admin_password,
    hostname      => $os_host_name,
    broker        => $broker_type,
    max_count     => 1,
    tags          => [ "${name}_tag" ],
    node_metadata => $metadata,
    task          => $os_image_version,
    transport     => Transport['razor']
  }

  if $ensure=='absent' {
    Rz_policy[$policy_name] -> Rz_tag["${name}_tag"]
  }
  else {
    Rz_tag["${name}_tag"] -> Rz_policy[$policy_name]
  }
}
