# Create SCVMM VM
define asm::vm::scvmm (
  $template,
  $path,
  $cpu_count,
  $memory_mb,
  $scvmm_server,
  $ensure                     = present,
  $description                = undef,
  $block_dynamic_optimization = false,
  $start_action               = undef,
  $stop_action                = undef,
  $vm_host                    = undef,
  $vm_cluster                 = undef,
  $domain                     = undef,
  $domain_username            = undef,
  $domain_password            = undef,
  $product_key                = undef,
  $scvmm_options              = undef,
  $highly_available           = true,  # cluster only option
  $network_interfaces         = undef,
  $decrypt                    = undef,
) {
  transport { 'winrm':
    name     => $scvmm_server,
    options  => $scvmm_options,
    provider => 'device_file',
  }

  if $decrypt {
    $provider = asm_decrypt
  } else {
    $provider = undef
  }

  sc_virtual_machine { $name:
    ensure                     => $ensure,
    description                => $description,
    template                   => $template,
    vm_host                    => $vm_host,
    vm_cluster                 => $vm_cluster,
    path                       => $path,
    block_dynamic_optimization => $block_dynamic_optimization,
    cpu_count                  => $cpu_count,
    memory_mb                  => $memory_mb,
    start_action               => $start_action,
    stop_action                => $stop_action,
    domain                     => $domain,
    domain_username            => $domain_username,
    domain_password            => $domain_password,
    product_key                => $product_key,
    highly_available           => $highly_available,
    provider                   => $provider,
    transport                  => Transport['winrm'],
  }

  if $ensure == "present" {
    if $network_interfaces {
      validate_hash($network_interfaces)
      create_resources(sc_virtual_network_adapter, $network_interfaces, {"ensure" => $ensure, "logical_network" => 'ConvergedNetSwitch'})
  
      Sc_virtual_network_adapter <||> {
        before => Exec["power_on ${name}"]
      }
    }

    exec { "power_on ${name}":
      command     => "Import-Module VirtualMachineManager; Get-VMMServer -ComputerName localhost; Start-SCVirtualMachine -VM ${name}",
      logoutput   => on_failure,
      provider    => 'winrm',
      require     => Sc_virtual_machine[$name],
      transport   => Transport['winrm'],
    }
  } else {
    exec { "power_off ${name}":
      command     => "Import-Module VirtualMachineManager; Get-VMMServer -ComputerName localhost; Stop-SCVirtualMachine -VM ${name} -Force",
      logoutput   => on_failure,
      provider    => 'winrm',
      before      => Sc_virtual_machine[$name],
      transport   => Transport['winrm'],
    }
  }
}
