# Equallogic volume
define asm::volume::equallogic (
  $size              = undef,
  $ensure            = present,
  $auth_ensure       = present,
  $thinprovision     = 'enable',
  $snapreserve       = '100%',
  $thinminreserve    = '10%',
  $thingrowthwarn    = '60%',
  $thingrowthmax     = '100%',
  $thinwarnsoftthres = '60%',
  $thinwarnhardthres = '90%',
  $multihostaccess   = 'enable',
  $auth_type         = undef,
  $chap_user_name    = undef,
  $passwd            = undef,
  $iqnorip           = undef,
  $decrypt           = false,
  $poolname          = 'default',
) {

  equallogic_volume { $name:
    ensure            => $ensure,
    state             => 'online',
    initsize          => $size,
    thinprovision     => $thinprovision,
    snapreserve       => $snapreserve,
    thinminreserve    => $thinminreserve,
    thingrowthwarn    => $thingrowthwarn,
    thingrowthmax     => $thingrowthmax,
    thinwarnsoftthres => $thinwarnsoftthres,
    thinwarnhardthres => $thinwarnhardthres,
    multihostaccess   => $multihostaccess,
    poolname          => $poolname,
  }

  # if we're removing the volume we can't also remove users
  # as other volumes might be owned by them and this will
  # either fail or end badly for those unrelated volumes
  if $ensure == 'present' {
    if $chap_user_name {
      equallogic_volume_chap_user { $chap_user_name:
        ensure        => $ensure,
        chap_password => $passwd,
        decrypt       => $decrypt,
        state         => 'enable',
        require       =>  Equallogic_volume[$name],
      }
    }

    if ($auth_type == 'chap') {
      equallogic_volume_access_chap { $name:
        ensure         => $auth_ensure,
        chap_user_name => $chap_user_name,
        require        => Equallogic_volume_chap_user[$chap_user_name],
      }
    }

    if $iqnorip {
      equallogic_volume_access_iqn { $name:
        ensure  => $auth_ensure,
        iqnorip => $iqnorip,
        require =>  Equallogic_volume[$name],
      }
    }
  }
}
