require 'spec_helper'

describe 'asm::cluster::scvmm' do

  let :title do
    'scvmm_cluster'
  end

  describe 'minimal parameters' do
    let :params do
      {
        'ipaddress' => '192.168.1.1',
        'host_group' => 'All Hosts\Demo',
        'scvmm_server' => '10.10.0.1',
        'hosts' => ['192.168.1.2', '192.168.1.3'],
        'username' => 'admin',
        'password' => 'pass',
      }
    end

    it 'should compile successfully' do
      should contain_transport('10.10.0.1').
        with_options({'timeout' => '600'})

      should contain_scvm_host_group('All Hosts\Demo')

      should_not contain_sc_run_as_account

      should contain_scvm_host('192.168.1.2').
        with_management_account(nil)

      should contain_scvm_host('192.168.1.3').with({
        :username => 'admin',
        :password => 'pass',
      })

      should contain_scvm_host_cluster('scvmm_cluster').with({
        :cluster_ipaddress => '192.168.1.1',
        :path => 'All Hosts\Demo',
        :username => 'admin',
        :password => 'pass',
        :fqdn => nil,
      })

      should contain_scvm_cluster_storage('scvmm_cluster').with({
        :host => '192.168.1.2',
        :path => 'All Hosts\Demo',
        :username => 'admin',
        :password => 'pass',
        :fqdn => nil,
      })

      should contain_sc_logical_network('ConvergedNetSwitch')

      should contain_sc_logical_network_definition('ConvergedNetSwitch').with({
        :logical_network => 'ConvergedNetSwitch',
        :host_groups => [],
        :subnet_vlans => [],
      })

      should contain_sc_vm_network('ConvergedNetSwitch')
    end
  end

  describe 'optional parameters' do
    let :params do
      {
        'ipaddress' => '192.168.1.1',
        'host_group' => 'All Hosts\Demo',
        'scvmm_server' => '10.10.0.1',
        'hosts' => ['192.168.1.2', '192.168.1.3'],
        'username' => 'admin',
        'password' => 'pass',
        'run_as_account_name' => 'jane',
        'fqdn' => 'example.com',
        'logical_network' => 'network1',
        'logical_network_hostgroups' => ['All Hosts\demo1'],
      }
    end

    it 'should compile successfully' do
      should contain_transport('10.10.0.1').
        with_options({'timeout' => '600'})

      should contain_scvm_host_group('All Hosts\Demo')

      should contain_sc_run_as_account('jane').with({
        :username => 'admin',
        :password => 'pass',
      })

      should contain_scvm_host('192.168.1.2').
        with_management_account('jane')

      should contain_scvm_host('192.168.1.3').with({
        :username => 'admin',
        :password => 'pass',
      })

      should contain_scvm_host_cluster('scvmm_cluster').with({
        :cluster_ipaddress => '192.168.1.1',
        :path => 'All Hosts\Demo',
        :username => 'admin',
        :password => 'pass',
        :fqdn => 'example.com'
      })

      should contain_scvm_cluster_storage('scvmm_cluster').with({
        :host => '192.168.1.2',
        :path => 'All Hosts\Demo',
        :username => 'admin',
        :password => 'pass',
        :fqdn => 'example.com'
      })

      should contain_sc_logical_network('network1')

      should contain_sc_logical_network_definition('network1').with({
        :logical_network => 'network1',
        :host_groups => ['All Hosts\demo1'],
        :subnet_vlans => [],
      })
    end
  end
end
