#! /usr/bin/env ruby -S rspec

require 'spec_helper'

describe "Create resources with type function" do

  let(:scope) { PuppetlabsSpec::PuppetInternals.scope }

  it "should exist" do
    Puppet::Parser::Functions.function("create_resources_with_type").should == "function_create_resources_with_type"
  end

  it 'should raise a Error if there are no arguments' do
    expect do
      scope.function_create_resources_with_type([])
    end.to raise_error(ArgumentError)
  end

  it 'should raise a Error if there more than one argument' do
    expect do
      scope.function_create_resources_with_type(['one', 'two'])
    end.to raise_error(ArgumentError)
  end

  it 'should raise an error if argument is not a hash' do
    expect do
      scope.function_create_resources_with_type(['one'])
    end.to raise_error(ArgumentError, /Expects a hash/)
  end

  it 'should call create resourcces once for every type of resource' do
    users  = {'dan'    => {'param_one' => 'value_one'}}
    groups = {'group1' => {'param_two' => 'value_two'}}
    scope.expects(:function_create_resources).with(['User', users])
    scope.expects(:function_create_resources).with(['Group', groups])
    scope.function_create_resources_with_type([
      {
        'user'  => users,
        'group' => groups
      },
    ])
  end

end
